Authors
=======

Main Authors
------------

* `Federico Tartarini`_
* `Stefano Schiavon`_

Contributors
------------

* `Akihisa Nomoto`_
* `Tyler Hoyt`_
* Chris Mackey
* `Jonas Kittner`_

.. _Federico Tartarini: https://www.linkedin.com/in/federico-tartarini-3991995b/
.. _Stefano Schiavon: https://www.linkedin.com/in/stefanoschiavon/
.. _Tyler Hoyt: https://www.linkedin.com/in/tyler-hoyt1/
.. _Jonas Kittner: https://github.com/jkittner/
.. _Akihisa Nomoto: https://www.linkedin.com/in/akihisa-nomoto-3b872611b/

Acknowledgements
----------------

`pythermalcomfort` is a derivative work of the following software projects:

* `CBE Comfort Tool`_ for indoor thermal comfort calculations. Available under GPL.
* `ladybug-comfort`_. Available under GPL.
* `UTCI`_ Fortran Code for outdoor thermal comfort calculations. Available under MIT.

.. _pythermalcomfort: https://pypi.org/project/pythermalcomfort/
.. _CBE Comfort Tool: https://comfort.cbe.berkeley.edu
.. _ladybug-comfort: https://pypi.org/project/ladybug-comfort/
.. _UTCI: https://www.utci.org/

Contact us
----------

If you need help, would like to ask a question about the tool, give us a feedback, or suggest a new feature you can now use `GitHub discussions <https://github.com/CenterForTheBuiltEnvironment/pythermalcomfort/discussions>`_.

Bug reports
-----------

You can report bugs or request new features using `GitHub issues <https://github.com/CenterForTheBuiltEnvironment/pythermalcomfort/issues>`_.
